package
module
Version:
v0.0.0-...-2de5858
Opens a new window with list of versions in this module.
Published: Aug 8, 2020
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
ssid

A tiny go package to get the SSID of the Wi-Fi you are connected to.
Runtime
- Go 1.14 or later
- macOS(darwin)
Installation
go get github.com/shmokmt/ssid
Usage
package main
import (
"github.com/shmokmt/ssid"
)
func main() {
fmt.Println(ssid.String())
}
References
LICENSE
MIT
Documentation
¶
a ssid package to get the SSID of the Wi-Fi you are coonected to.
String creates the ssid.
Support only drawin(macOS)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.